import { Link } from "wouter";
import { Calculator, Heart, Home, Check, Award, Users, Clock, ChevronRight, ArrowRight } from "lucide-react";
import { Button } from "@/components/ui/button";
import { Card, CardContent } from "@/components/ui/card";
import { useReveal } from "@/hooks/use-reveal";
import heroLogo from "@assets/logo 2_1749573408738.webp";

// Using Unsplash for high-quality family photo
const familyPhotoUrl = "https://images.unsplash.com/photo-1511895426328-dc8714191300?ixlib=rb-4.0.3&ixid=M3wxMjA3fDB8MHxwaG90by1wYWdlfHx8fGVufDB8fHx8fA%3D%3D&auto=format&fit=crop&w=2070&q=80";

export default function HomePage() {
  const servicesReveal = useReveal();
  const card1Reveal = useReveal();
  const card2Reveal = useReveal();
  const card3Reveal = useReveal();
  const statsReveal = useReveal();
  const whyChooseReveal = useReveal();
  const ctaReveal = useReveal();

  return (
    <div>
      {/* Hero Section */}
      <section 
        className="relative h-screen flex items-center justify-center text-white"
        style={{
          backgroundImage: `linear-gradient(rgba(0, 0, 0, 0.4), rgba(0, 0, 0, 0.4)), url(${familyPhotoUrl})`,
          backgroundSize: 'cover',
          backgroundPosition: 'center',
          backgroundRepeat: 'no-repeat'
        }}
        role="banner"
        aria-label="Virginia Harris Enterprise hero section"
      >
        <div className="relative z-10 max-w-4xl mx-auto px-4 sm:px-6 lg:px-8 text-center">
          <div className="mb-8">
            <img 
              src={heroLogo} 
              alt="Virginia Harris Enterprise" 
              className="h-48 md:h-64 w-auto mx-auto"
              width="256"
              height="256"
              loading="eager"
            />
          </div>
          <h2 className="text-5xl md:text-6xl font-bold mb-4 leading-tight">
            Empowering Your Success
          </h2>
          <p className="text-xl md:text-2xl mb-8 font-light max-w-3xl mx-auto">
            Expert tax and insurance solutions delivered with integrity and excellence.
          </p>
          <div className="flex flex-col sm:flex-row gap-4 justify-center">
            <Button asChild size="lg" className="bg-accent hover:bg-yellow-600 text-lg px-8 py-4">
              <Link href="/contact">
                Get Started
                <ChevronRight className="ml-2 h-5 w-5" />
              </Link>
            </Button>
            <Button asChild size="lg" variant="outline" className="text-lg px-8 py-4 border-white text-white hover:bg-white hover:text-charcoal bg-[#ffffff00]">
              <Link href="/services">
                Learn More
              </Link>
            </Button>
          </div>
        </div>
      </section>

      {/* About and Services Section */}
      <section className="py-20 bg-neutral-light">
        <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
          <div 
            ref={servicesReveal.ref}
            className={`text-center mb-16 transition-all duration-1000 ${
              servicesReveal.isVisible 
                ? 'opacity-100 translate-y-0' 
                : 'opacity-0 translate-y-8'
            }`}
          >
            <h2 className="text-3xl md:text-4xl font-bold text-charcoal mb-6">
              About Us
            </h2>
            <p className="text-lg text-gray-600 max-w-4xl mx-auto mb-8">
              Virginia Harris Enterprise has helped businesses and individuals succeed for over 20 years. We believe in honesty, great service, and making every client feel important.
            </p>
          </div>

          {/* Services Overview */}
          <div className="mb-16 bg-white rounded-lg p-8 shadow-sm">
            <h2 className="text-3xl font-bold text-charcoal mb-6">Our Services</h2>
            <p className="text-lg text-gray-600 mb-6">
              We offer a wide range of consulting services, including:
            </p>
            <div className="grid md:grid-cols-2 gap-8">
              <ul className="space-y-3 text-lg text-gray-700">
                <li className="flex items-center">
                  <Check className="h-5 w-5 text-primary mr-3" />
                  Tax preparation and planning
                </li>
                <li className="flex items-center">
                  <Check className="h-5 w-5 text-primary mr-3" />
                  Life and health insurance
                </li>
                <li className="flex items-center">
                  <Check className="h-5 w-5 text-primary mr-3" />
                  Business consulting
                </li>
                <li className="flex items-center">
                  <Check className="h-5 w-5 text-primary mr-3" />
                  Financial planning
                </li>
              </ul>
              <div>
                <p className="text-lg text-gray-600">
                  We tailor every service to fit your needs.
                </p>
              </div>
            </div>
          </div>

          <div className="grid md:grid-cols-2 lg:grid-cols-3 gap-8">
            {/* Tax Services Card */}
            <div 
              ref={card1Reveal.ref}
              className={`transition-all duration-1000 delay-200 ${
                card1Reveal.isVisible 
                  ? 'opacity-100 translate-y-0 scale-100' 
                  : 'opacity-0 translate-y-8 scale-95'
              }`}
            >
              <Card className="hover:shadow-xl transition-shadow duration-300">
                <CardContent className="p-8">
                <div className="text-center mb-6">
                  <div className="bg-primary text-white w-16 h-16 rounded-full flex items-center justify-center mx-auto mb-4">
                    <Calculator className="h-8 w-8" />
                  </div>
                  <h3 className="text-xl font-bold text-charcoal mb-2">Tax Preparation</h3>
                </div>
                <ul className="space-y-3 text-gray-600">
                  <li className="flex items-center">
                    <Check className="h-5 w-5 text-primary mr-3" />
                    Personal Tax Returns
                  </li>
                  <li className="flex items-center">
                    <Check className="h-5 w-5 text-primary mr-3" />
                    Business Tax Filing
                  </li>
                  <li className="flex items-center">
                    <Check className="h-5 w-5 text-primary mr-3" />
                    Tax Planning Strategies
                  </li>
                  <li className="flex items-center">
                    <Check className="h-5 w-5 text-primary mr-3" />
                    IRS Representation
                  </li>
                  <li className="flex items-center">
                    <Check className="h-5 w-5 text-primary mr-3" />
                    Tax Relief Options
                  </li>
                </ul>
                <div className="mt-6 text-center">
                  <Button asChild size="sm" className="bg-primary hover:bg-primary-dark">
                    <Link href="/contact">
                      Get Free Tax Consultation
                    </Link>
                  </Button>
                </div>
                </CardContent>
              </Card>
            </div>

            {/* Life Insurance Card */}
            <div 
              ref={card2Reveal.ref}
              className={`transition-all duration-1000 delay-400 ${
                card2Reveal.isVisible 
                  ? 'opacity-100 translate-y-0 scale-100' 
                  : 'opacity-0 translate-y-8 scale-95'
              }`}
            >
              <Card className="hover:shadow-xl transition-shadow duration-300">
                <CardContent className="p-8">
                <div className="text-center mb-6">
                  <div className="bg-secondary text-white w-16 h-16 rounded-full flex items-center justify-center mx-auto mb-4">
                    <Heart className="h-8 w-8" />
                  </div>
                  <h3 className="text-xl font-bold text-charcoal mb-2">Life Insurance</h3>
                </div>
                <ul className="space-y-3 text-gray-600">
                  <li className="flex items-center">
                    <Check className="h-5 w-5 text-primary mr-3" />
                    Term Life Insurance
                  </li>
                  <li className="flex items-center">
                    <Check className="h-5 w-5 text-primary mr-3" />
                    Whole Life Insurance
                  </li>
                  <li className="flex items-center">
                    <Check className="h-5 w-5 text-primary mr-3" />
                    Universal Life Plans
                  </li>
                  <li className="flex items-center">
                    <Check className="h-5 w-5 text-primary mr-3" />
                    Group Life Coverage
                  </li>
                  <li className="flex items-center">
                    <Check className="h-5 w-5 text-primary mr-3" />
                    Beneficiary Planning
                  </li>
                </ul>
                </CardContent>
              </Card>
            </div>

            {/* Health Insurance Card */}
            <div 
              ref={card3Reveal.ref}
              className={`transition-all duration-1000 delay-600 ${
                card3Reveal.isVisible 
                  ? 'opacity-100 translate-y-0 scale-100' 
                  : 'opacity-0 translate-y-8 scale-95'
              }`}
            >
              <Card className="hover:shadow-xl transition-shadow duration-300">
                <CardContent className="p-8">
                <div className="text-center mb-6">
                  <div className="bg-accent text-white w-16 h-16 rounded-full flex items-center justify-center mx-auto mb-4">
                    <Home className="h-8 w-8" />
                  </div>
                  <h3 className="text-xl font-bold text-charcoal mb-2">Health & Home Insurance</h3>
                </div>
                <ul className="space-y-3 text-gray-600">
                  <li className="flex items-center">
                    <Check className="h-5 w-5 text-primary mr-3" />
                    Health Insurance Plans
                  </li>
                  <li className="flex items-center">
                    <Check className="h-5 w-5 text-primary mr-3" />
                    Home Insurance Coverage
                  </li>
                  <li className="flex items-center">
                    <Check className="h-5 w-5 text-primary mr-3" />
                    Auto Insurance Policies
                  </li>
                  <li className="flex items-center">
                    <Check className="h-5 w-5 text-primary mr-3" />
                    Business Insurance
                  </li>
                  <li className="flex items-center">
                    <Check className="h-5 w-5 text-primary mr-3" />
                    Claims Assistance
                  </li>
                </ul>
                <div className="mt-6 text-center">
                  <Button asChild size="sm" className="bg-accent hover:bg-accent/90">
                    <Link href="/contact">
                      Get Free Insurance Quote
                    </Link>
                  </Button>
                </div>
                </CardContent>
              </Card>
            </div>
          </div>
        </div>
      </section>

      {/* Why Choose Us */}
      <section className="py-20 bg-white">
        <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
          <div className="grid lg:grid-cols-2 gap-12 items-center">
            <div 
              ref={whyChooseReveal.ref}
              className={`transition-all duration-1000 ${
                whyChooseReveal.isVisible 
                  ? 'opacity-100 translate-x-0' 
                  : 'opacity-0 -translate-x-8'
              }`}
            >
              <h2 className="text-3xl md:text-4xl font-bold text-charcoal mb-6">
                Why Choose Virginia Harris Enterprise?
              </h2>

              <div className="mb-6 p-4 bg-neutral-light rounded-lg">
                <h3 className="text-xl font-semibold text-charcoal mb-3">Professional Credentials & Trust Signals</h3>
                <ul className="space-y-2 text-gray-700">
                  <li className="flex items-center">
                    <Check className="h-5 w-5 text-primary mr-3 flex-shrink-0" />
                    <strong>Certified Tax Professional (CTP)</strong> - Virginia Harris
                  </li>
                  <li className="flex items-center">
                    <Check className="h-5 w-5 text-primary mr-3 flex-shrink-0" />
                    <strong>Licensed Insurance Agent</strong> - Georgia State Licensed
                  </li>
                  <li className="flex items-center">
                    <Check className="h-5 w-5 text-primary mr-3 flex-shrink-0" />
                    <strong>15+ Years Experience</strong> serving Atlanta Metro families
                  </li>
                  <li className="flex items-center">
                    <Check className="h-5 w-5 text-primary mr-3 flex-shrink-0" />
                    <strong>Continuing Education</strong> - Current with tax law changes
                  </li>
                </ul>
              </div>

              <ul className="space-y-4 text-lg text-gray-700">
                <li className="flex items-center">
                  <Check className="h-6 w-6 text-primary mr-4 flex-shrink-0" />
                  <div>
                    <strong>Personalized Service:</strong> Every client receives individual attention and customized solutions
                  </div>
                </li>
                <li className="flex items-center">
                  <Check className="h-6 w-6 text-primary mr-4 flex-shrink-0" />
                  <div>
                    <strong>Free Consultations:</strong> No-obligation initial meetings for all new clients
                  </div>
                </li>
                <li className="flex items-center">
                  <Check className="h-6 w-6 text-primary mr-4 flex-shrink-0" />
                  <div>
                    <strong>Local Expertise:</strong> Deep knowledge of Georgia tax laws and Atlanta market
                  </div>
                </li>
                <li className="flex items-center">
                  <Check className="h-6 w-6 text-primary mr-4 flex-shrink-0" />
                  <div>
                    <strong>Year-Round Support:</strong> Available for questions and guidance beyond tax season
                  </div>
                </li>
              </ul>

              <div className="mt-8">
                <Button asChild size="lg" className="bg-primary hover:bg-primary-dark text-lg px-8 py-4">
                  <Link href="/contact">
                    Schedule Your Free Consultation Today
                    <ArrowRight className="ml-2 h-5 w-5" />
                  </Link>
                </Button>
              </div>
            </div>

            <div className="relative">
              <img
                src="https://images.unsplash.com/photo-1560472354-b33ff0c44a43?ixlib=rb-4.0.3&ixid=MnwxMjA3fDB8MHxwaG90by1wYWdlfHx8fGVufDB8fHx8&auto=format&fit=crop&w=800&h=600"
                alt="Professional consultation"
                className="rounded-xl shadow-lg w-full h-auto"
              />
            </div>
          </div>
        </div>
      </section>

      {/* Client Testimonials Section */}
      <section className="py-20 bg-neutral-light">
        <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
          <div className="text-center mb-16">
            <h2 className="text-3xl md:text-4xl font-bold text-charcoal mb-4">
              What Our Clients Say
            </h2>
            <p className="text-lg text-gray-600 max-w-3xl mx-auto">
              Real testimonials from Atlanta families and businesses we've helped achieve their financial goals
            </p>
          </div>

          <div className="grid md:grid-cols-2 lg:grid-cols-3 gap-8">
            <Card className="bg-white shadow-lg hover:shadow-xl transition-shadow duration-300">
              <CardContent className="p-8">
                <div className="mb-4">
                  <div className="flex text-yellow-400 mb-3">
                    {"★".repeat(5)}
                  </div>
                  <p className="text-gray-600 italic mb-4">
                    "Virginia saved our family over $3,000 on our taxes last year. Her expertise with Georgia tax laws is exceptional, and she found deductions we never knew existed."
                  </p>
                </div>
                <div className="flex items-center">
                  <div className="w-12 h-12 bg-primary text-white rounded-full flex items-center justify-center mr-4">
                    <span className="font-semibold">MJ</span>
                  </div>
                  <div>
                    <p className="font-semibold text-charcoal">Michael & Jennifer R.</p>
                    <p className="text-gray-500 text-sm">Sandy Springs Family</p>
                  </div>
                </div>
              </CardContent>
            </Card>

            <Card className="bg-white shadow-lg hover:shadow-xl transition-shadow duration-300">
              <CardContent className="p-8">
                <div className="mb-4">
                  <div className="flex text-yellow-400 mb-3">
                    {"★".repeat(5)}
                  </div>
                  <p className="text-gray-600 italic mb-4">
                    "As a small business owner, I needed both tax help and insurance coverage. Virginia handled everything professionally and saved me time and money on both services."
                  </p>
                </div>
                <div className="flex items-center">
                  <div className="w-12 h-12 bg-secondary text-white rounded-full flex items-center justify-center mr-4">
                    <span className="font-semibold">DM</span>
                  </div>
                  <div>
                    <p className="font-semibold text-charcoal">David Martinez</p>
                    <p className="text-gray-500 text-sm">Atlanta Business Owner</p>
                  </div>
                </div>
              </CardContent>
            </Card>

            <Card className="bg-white shadow-lg hover:shadow-xl transition-shadow duration-300">
              <CardContent className="p-8">
                <div className="mb-4">
                  <div className="flex text-yellow-400 mb-3">
                    {"★".repeat(5)}
                  </div>
                  <p className="text-gray-600 italic mb-4">
                    "The insurance claim process was overwhelming until Virginia stepped in. She fought for us and got our claim approved quickly. Highly recommend!"
                  </p>
                </div>
                <div className="flex items-center">
                  <div className="w-12 h-12 bg-accent text-white rounded-full flex items-center justify-center mr-4">
                    <span className="font-semibold">LT</span>
                  </div>
                  <div>
                    <p className="font-semibold text-charcoal">Lisa Thompson</p>
                    <p className="text-gray-500 text-sm">Buckhead Resident</p>
                  </div>
                </div>
              </CardContent>
            </Card>
          </div>

          <div className="text-center mt-12">
            <p className="text-lg text-gray-600 mb-6">
              Join hundreds of satisfied clients who trust Virginia Harris Enterprise
            </p>
            <Button asChild size="lg" className="bg-primary hover:bg-primary-dark text-lg px-8 py-4">
              <Link href="/contact">
                Start Your Success Story Today
                <ArrowRight className="ml-2 h-5 w-5" />
              </Link>
            </Button>
          </div>
        </div>
      </section>

      {/* Enhanced CTA Section */}
      <section className="py-20 bg-primary text-white">
        <div className="max-w-4xl mx-auto px-4 sm:px-6 lg:px-8 text-center">
          <div 
            ref={ctaReveal.ref}
            className={`transition-all duration-1000 ${
              ctaReveal.isVisible 
                ? 'opacity-100 translate-y-0' 
                : 'opacity-0 translate-y-8'
            }`}
          >
            <h2 className="text-3xl md:text-4xl font-bold mb-6">
              Ready to Secure Your Financial Future?
            </h2>
            <p className="text-xl opacity-90 mb-4">
              Take the first step toward better taxes and comprehensive insurance protection
            </p>
            <p className="text-lg opacity-80 mb-8">
              <strong>FREE Consultation</strong> • <strong>No Obligation</strong> • <strong>Expert Guidance</strong> • <strong>Atlanta Local</strong>
            </p>
            
            <div className="grid md:grid-cols-2 gap-6 mb-8">
              <div className="bg-white/10 backdrop-blur rounded-lg p-6">
                <h3 className="text-xl font-semibold mb-3">Tax Services</h3>
                <p className="opacity-90 mb-4">Get expert tax preparation and planning that saves you money</p>
                <Button asChild size="lg" variant="secondary" className="w-full">
                  <Link href="/contact">
                    Get Free Tax Consultation
                  </Link>
                </Button>
              </div>
              
              <div className="bg-white/10 backdrop-blur rounded-lg p-6">
                <h3 className="text-xl font-semibold mb-3">Insurance Services</h3>
                <p className="opacity-90 mb-4">Protect what matters most with comprehensive coverage</p>
                <Button asChild size="lg" variant="secondary" className="w-full">
                  <Link href="/contact">
                    Get Free Insurance Quote
                  </Link>
                </Button>
              </div>
            </div>

            <div className="flex flex-col sm:flex-row gap-4 justify-center">
              <Button asChild size="lg" variant="secondary" className="text-lg px-8 py-4">
                <Link href="/contact">
                  Contact Us Today
                  <ArrowRight className="ml-2 h-5 w-5" />
                </Link>
              </Button>
              <Button asChild size="lg" variant="outline" className="text-lg px-8 py-4 border-white text-white hover:bg-white hover:text-primary">
                <Link href="tel:+18777728763">
                  Call (877) 772-8763
                </Link>
              </Button>
            </div>

            <div className="mt-8 text-sm opacity-75">
              <p>Serving Atlanta Metro • Licensed & Certified • 15+ Years Experience</p>
            </div>
          </div>
        </div>
      </section>
    </div>
  );
}